@@ -2,7 +2,7 @@
 # Package       HiPi::Class
 # Description:  base class
 # Created       Sat Nov 24 15:51:05 2012
-# SVN Id        $Id: Class.pm 446 2013-02-01 02:55:27Z Mark Dootson $
+# SVN Id        $Id: Class.pm 1026 2013-03-11 08:55:02Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -14,75 +14,21 @@ package HiPi::Class;
 
 #########################################################################################
 
-=head1 NAME
-
-HiPi::Class
-
-=head1 VERSION
-
-Version 0.01
-
-=head1 SYNOPSYS
-
-    use HiPi::Constant qw( :raspberry :pinmode :serial
-        :spi :i2c :wiring :bcm2835 :mcp23017 :htv2cmd
-        :htv2baudrate );
-        
-    use HiPi::BCM2835 qw( :registers :memory :function
-        :pud :pad :pins :spi :pwm);
-        
-    use HiPi::GPIO::PAD1;
-    use HiPi::GPIO::PAD5;
-    use HiPi::Wiring;
-    use HiPi::Control::LCD::HTBackpackV2
-    use HiPi::Control::LCD::SerLCD
-    use HiPi::MCP23017;
-
-=head1 DESCRIPTION
-
-This module is not normally used directly in end user code
-    
-=head1 LICENSE
-
-This work is free software; you can redistribute it and/or modify it 
-under the terms of the GNU General Public License as published by the 
-Free Software Foundation; either version 3 of the License, or any later 
-version.
-
-=head3 License Note
-
-I would normally release any Perl code under the Perl Artistic License
-but this module wraps several GPL / LGPL C libraries and I feel that
-the licensing of the entire distribution is simpler if the Perl code
-is under GPL too.
-
-=head1 AUTHOR
-
-Mark Dootson, C<< <mdootson at cpan.org> >>
-
-=head1 COPYRIGHT
-
-Copyright (C) 2012-2013 Mark Dootson, all rights reserved.
-
-=cut
-
-
-
 use strict;
 use warnings;
 require Exporter;
 use base qw( Exporter );
 
-our $VERSION = '0.10';
+our $VERSION = '0.20';
 
 #-------------------------------------------------------------------
 # Object Constructor
 #-------------------------------------------------------------------
 
 sub new {
-    my ($class, $params) = @_;
+    my ( $class, %params ) = @_;
     my $self = bless {'__hipi_instance_data' => {} }, $class;
-    $self->init_hipi_object($params);
+    return $self->init_hipi_object( %params );
 }
 
 #-------------------------------------------------------------------
@@ -104,10 +50,10 @@ sub new {
 #-------------------------------------------------------------------
 
 sub init_hipi_object {
-    my ($self, $params) = @_;
-    foreach my $key (sort keys( %$params ) ) {
+    my ($self, %params) = @_;
+    foreach my $key (sort keys( %params ) ) {
         my $dataname = lc($key);
-        $self->{__hipi_instance_data}->{$dataname} = $params->{$key};
+        $self->{__hipi_instance_data}->{$dataname} = $params{$key};
     }
     return $self;
 }
@@ -252,3 +198,5 @@ sub set_hipi_object_data {
 }
 
 1;
+
+__END__
